@@ -202,8 +202,10 @@ typedef irqreturn_t(*FN_ISR) (int irq, void *dev_id, struct pt_regs *ptregs);
 #endif /* LINUX_VERS >= 4.11.0 */
 
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 29)
+#if LINUX_VERSION_CODE < KERNEL_VERSION(6, 13, 0)
 #include <net/lib80211.h>
 #endif
+#endif
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 29)
 #include <linux/ieee80211.h>
 #else
@@ -405,10 +407,17 @@ extern void timer_cb_compat(struct timer_list *tl);
 #define timer_set_private(timer_compat, priv) (timer_compat)->arg = priv
 #define timer_expires(timer_compat) (timer_compat)->timer.expires
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(6, 15, 0)
+#define timer_delete(t) timer_delete(&((t)->timer))
+#ifndef timer_delete_sync
+#define timer_delete_sync(t) timer_delete_sync(&((t)->timer))
+#endif
+#else
 #define del_timer(t) del_timer(&((t)->timer))
 #ifndef del_timer_sync
 #define del_timer_sync(t) del_timer_sync(&((t)->timer))
 #endif
+#endif
 #define timer_pending(t) timer_pending(&((t)->timer))
 #define add_timer(t) add_timer(&((t)->timer))
 #define mod_timer(t, j) mod_timer(&((t)->timer), j)
@@ -485,8 +494,13 @@ static inline void tasklet_init(struct tasklet_struct *tasklet,
 
 #define tasklet_kill(tasklet)	{ do {} while (0); }
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(6, 15, 0)
+/* 6.15.x introduced timer_delete_sync() */
+#define timer_delete_sync(timer) timer_delete(timer)
+#else
 /* 2.4.x introduced del_timer_sync() */
 #define del_timer_sync(timer) del_timer(timer)
+#endif
 
 #else
 
@@ -978,9 +992,9 @@ static inline struct inode *file_inode(const struct file *f)
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 14, 0)
 // New google android GKI not allow kernel_write/kernel_read, and use
 // below for temporary overcome, and waiting for get rid of that for future
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 4, 0)
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(5, 4, 0) && LINUX_VERSION_CODE < KERNEL_VERSION(6, 13, 0))
 MODULE_IMPORT_NS(VFS_internal_I_am_really_a_filesystem_and_am_NOT_a_driver);
-#endif // LINUX_VERSION_CODE >= KERNEL_VERSION(5, 4, 0)
+#endif // LINUX_VERSION_CODE >= KERNEL_VERSION(5, 4, 0) && LINUX_VERSION_CODE < KERNEL_VERSION(6, 13, 0)
 #define vfs_write(fp, buf, len, pos) kernel_write(fp, buf, len, pos)
 #define vfs_read(fp, buf, len, pos) kernel_read(fp, buf, len, pos)
 int kernel_read_compat(struct file *file, loff_t offset, char *addr, unsigned long count);
